@@ -15,7 +15,7 @@ from .mapper import ModelAttributeAdapter, ModelAttribute
 from sqlalchemy.schema import Sequence as SA_Sequence, Column as SA_Column
 from sqlalchemy import types, CheckConstraint
 from sqlalchemy_utils.types.color import ColorType
-from sqlalchemy_utils.types.encrypted.encrypted_type import EncryptedType
+from sqlalchemy_utils.types.encrypted.encrypted_type import StringEncryptedType
 from sqlalchemy_utils.types.password import PasswordType, Password as SAU_PWD
 from sqlalchemy_utils.types.uuid import UUIDType
 from sqlalchemy_utils.types.url import URLType
@@ -282,10 +282,18 @@ class Column(Field):
 
         if self.encrypt_key:
             encrypt_key = self.format_encrypt_key(registry, namespace)
-            sqlalchemy_type = EncryptedType(sqlalchemy_type, encrypt_key)
+            sqlalchemy_type = self.get_encrypt_key_type(
+                registry, sqlalchemy_type, encrypt_key)
 
         return SA_Column(db_column_name, sqlalchemy_type, *args, **kwargs)
 
+    def get_encrypt_key_type(self, registry, sqlalchemy_type, encrypt_key):
+        sqlalchemy_type = StringEncryptedType(sqlalchemy_type, encrypt_key)
+        if sgdb_in(registry.engine, ['MySQL', 'MariaDB']):
+            sqlalchemy_type.impl = types.String(64)
+
+        return sqlalchemy_type
+
     def format_encrypt_key(self, registry, namespace):
         """Format and return the encyption key
 
@@ -298,8 +306,8 @@ class Column(Field):
             encrypt_key = Configuration.get('default_encrypt_key')
 
         if not encrypt_key:
-            raise FieldException("No encrypt_key defined in the "
-                                 "configuration")
+            raise FieldException(  # pragma: no cover
+                "No encrypt_key defined in the configuration")
 
         def wrapper():
             """Return encrypt_key wrapper
@@ -446,7 +454,7 @@ class Decimal(Column):
 
     def getter_format_value(self, value):
         if value is None:
-            return None
+            return None  # pragma: no cover
 
         if self.encrypt_key:
             value = decimal.Decimal(value)
@@ -488,7 +496,8 @@ def convert_string_to_datetime(value):
     elif isinstance(value, str):
         return parse(value)
 
-    return value
+    raise FieldException(
+        "We can't convert this value %s to datetime")
 
 
 def add_timezone_on_datetime(dt, default_timezone):
@@ -529,7 +538,7 @@ class DateTimeType(types.TypeDecorator):
 
     @property
     def python_type(self):
-        return datetime
+        return datetime  # pragma: no cover
 
 
 class DateTime(Column):
@@ -719,6 +728,13 @@ class String(Column):
         res['size'] = self.size
         return res
 
+    def get_encrypt_key_type(self, registry, sqlalchemy_type, encrypt_key):
+        sqlalchemy_type = StringEncryptedType(sqlalchemy_type, encrypt_key)
+        if sgdb_in(registry.engine, ['MySQL', 'MariaDB']):
+            sqlalchemy_type.impl = types.String(max(self.size, 64))
+
+        return sqlalchemy_type
+
 
 class Enum(Column):
     """Enum column
@@ -762,11 +778,7 @@ class MsSQLPasswordType(PasswordType):
     impl = types.VARCHAR(1024)
 
     def load_dialect_impl(self, dialect):
-        if dialect.name == 'mssql':
-            # Use a BLOB type for sqlite
-            return dialect.type_descriptor(types.VARCHAR(self.length))
-
-        return super(MsSQLPasswordType, self).load_dialect_impl(dialect)
+        return dialect.type_descriptor(types.VARCHAR(self.length))
 
 
 class Password(Column):
@@ -820,7 +832,7 @@ class Password(Column):
         :param value:
         :return:
         """
-        value = self.sqlalchemy_type.context.encrypt(value).encode('utf8')
+        value = self.sqlalchemy_type.context.hash(value).encode('utf8')
         value = SAU_PWD(value, context=self.sqlalchemy_type.context)
         return value
 
@@ -873,10 +885,17 @@ class Text(Column):
     """
     sqlalchemy_type = TextType
 
+    def get_encrypt_key_type(self, registry, sqlalchemy_type, encrypt_key):
+        sqlalchemy_type = StringEncryptedType(sqlalchemy_type, encrypt_key)
+        if sgdb_in(registry.engine, ['MySQL', 'MariaDB']):
+            sqlalchemy_type.impl = types.Text()
+
+        return sqlalchemy_type
+
 
 class StrSelection(str):
     """Class representing the data of one column Selection """
-    selections = {}
+    selections = dumps({})
     registry = None
     namespace = None
 
@@ -885,11 +904,12 @@ class StrSelection(str):
 
         :return: selections dict
         """
-        if isinstance(self.selections, dict):
-            return self.selections
-        if isinstance(self.selections, str):
+        selections = loads(self.selections)
+        if isinstance(selections, dict):
+            return selections
+        if isinstance(selections, str):
             m = self.registry.get(self.namespace)
-            return dict(getattr(m, self.selections)())
+            return dict(getattr(m, selections)())
 
     def validate(self):
         """Validate if the key is in the selections
@@ -922,7 +942,7 @@ class SelectionType(types.TypeDecorator):
         elif isinstance(selections, (list, tuple)):
             self.selections = dict(selections)
         else:
-            raise FieldException(
+            raise FieldException(  # pragma: no cover
                 "selection wainting 'dict', get %r" % type(selections))
 
         if isinstance(self.selections, dict):
@@ -930,10 +950,11 @@ class SelectionType(types.TypeDecorator):
                 if not isinstance(k, str):
                     raise FieldException('The key must be a str')
                 if len(k) > 64:
-                    raise Exception(
+                    raise Exception(  # pragma: no cover
                         '%r is too long %r, waiting max %s or use size arg' % (
                             k, len(k), size))
 
+        self.selections = dumps(self.selections)
         self._StrSelection = type('StrSelection', (StrSelection,),
                                   {'selections': self.selections,
                                    'registry': registry,
@@ -1085,7 +1106,7 @@ class Selection(Column):
             # No check constraint in MariaDB
             return []
 
-        selections = self.sqlalchemy_type.selections
+        selections = loads(self.sqlalchemy_type.selections)
         if isinstance(selections, dict):
             enum = selections.keys()
         else:
@@ -1113,6 +1134,13 @@ class Selection(Column):
 
         return []
 
+    def get_encrypt_key_type(self, registry, sqlalchemy_type, encrypt_key):
+        sqlalchemy_type = StringEncryptedType(sqlalchemy_type, encrypt_key)
+        if sgdb_in(registry.engine, ['MySQL', 'MariaDB']):
+            sqlalchemy_type.impl = types.String(max(self.size, 64))
+
+        return sqlalchemy_type
+
 
 """
     Added *process_result_value* at the class *JSON*, because
@@ -1160,6 +1188,13 @@ class Json(Column):
 
         return value
 
+    def get_encrypt_key_type(self, registry, sqlalchemy_type, encrypt_key):
+        sqlalchemy_type = StringEncryptedType(sqlalchemy_type, encrypt_key)
+        if sgdb_in(registry.engine, ['MySQL', 'MariaDB']):
+            sqlalchemy_type.impl = types.Text()
+
+        return sqlalchemy_type
+
 
 class LargeBinary(Column):
     """Large binary column
@@ -1200,6 +1235,13 @@ class LargeBinary(Column):
 
         return value
 
+    def get_encrypt_key_type(self, registry, sqlalchemy_type, encrypt_key):
+        sqlalchemy_type = StringEncryptedType(sqlalchemy_type, encrypt_key)
+        if sgdb_in(registry.engine, ['MySQL', 'MariaDB']):
+            sqlalchemy_type.impl = types.Text()
+
+        return sqlalchemy_type
+
 
 class Sequence(String):
     """Sequence column
@@ -1248,7 +1290,9 @@ class Sequence(String):
         :param fieldname: the fieldname of the model
         :return:
         """
-        if not hasattr(registry, '_need_sequence_to_create_if_not_exist'):
+        if not hasattr(
+            registry, '_need_sequence_to_create_if_not_exist'
+        ):  # pragma: no cover
             registry._need_sequence_to_create_if_not_exist = []
         elif registry._need_sequence_to_create_if_not_exist is None:
             registry._need_sequence_to_create_if_not_exist = []
@@ -1309,6 +1353,13 @@ class Color(Column):
         res['size'] = self.max_length
         return res
 
+    def get_encrypt_key_type(self, registry, sqlalchemy_type, encrypt_key):
+        sqlalchemy_type = StringEncryptedType(sqlalchemy_type, encrypt_key)
+        if sgdb_in(registry.engine, ['MySQL', 'MariaDB']):
+            sqlalchemy_type.impl = types.String(max(self.max_length, 64))
+
+        return sqlalchemy_type
+
 
 class UUID(Column):
     """UUID column
@@ -1427,6 +1478,13 @@ class PhoneNumber(Column):
         res['max_length'] = self.max_length
         return res
 
+    def get_encrypt_key_type(self, registry, sqlalchemy_type, encrypt_key):
+        sqlalchemy_type = StringEncryptedType(sqlalchemy_type, encrypt_key)
+        if sgdb_in(registry.engine, ['MySQL', 'MariaDB']):
+            sqlalchemy_type.impl = types.String(max(self.max_length, 64))
+
+        return sqlalchemy_type
+
 
 """
     Added *process_result_value* at the class *EmailType*, because
@@ -1459,7 +1517,8 @@ class Email(Column):
         """
         if value is not None:
             return value.lower()
-        return value
+
+        return value  # pragma: no cover
 
 
 class CountryType(types.TypeDecorator, ScalarCoercible):
@@ -1475,16 +1534,13 @@ class CountryType(types.TypeDecorator, ScalarCoercible):
         return value
 
     def process_result_value(self, value, dialect):
-        if value:
-            return pycountry.countries.get(alpha_3=value)
-
-        return value
+        return self._coerce(value)
 
     def _coerce(self, value):
         if value is not None and not isinstance(value, self.python_type):
             return pycountry.countries.get(alpha_3=value)
 
-        return value
+        return value  # pragma: no cover
 
 
 class Country(Column):
@@ -1508,7 +1564,7 @@ class Country(Column):
     def __init__(self, mode='alpha_2', *args, **kwargs):
         self.mode = mode
         if pycountry is None:
-            raise FieldException(
+            raise FieldException(  # pragma: no cover
                 "'pycountry' package is required for use 'CountryType'")
 
         self.choices = {getattr(country, mode): country.name
