@@ -30,7 +30,7 @@ from anyblok.column import (
     CompareType, Column, Boolean, Json, String, BigInteger, Text, Selection,
     Date, DateTime, Time, Interval, Decimal, Float, LargeBinary, Integer,
     Sequence, Color, Password, UUID, URL, PhoneNumber, Email, Country,
-    TimeStamp, Enum, add_timezone_on_datetime)
+    TimeStamp, Enum, add_timezone_on_datetime, convert_string_to_datetime)
 
 
 time_params = [DateTime]
@@ -63,6 +63,7 @@ COLUMNS = [
     (Time, datetime.time(), {}),
     (Float, 1., {}),
     (Integer, 1, {}),
+    (Integer, 1, {'sequence': 'foo'}),
     (Email, 'jhon@doe.com', {}),
     (LargeBinary, urandom(100), {}),
     (Interval, datetime.timedelta(days=6), {}),
@@ -256,11 +257,15 @@ class TestColumns:
         assert test.col == 1
         res = registry.execute('select id from test where another_name=1')
         assert res.fetchone()[0] == test.id
+        ma = ModelAttribute('Model.Test', 'col')
+        assert ma.get_column_name(registry) == 'another_name'
 
     def test_column_with_foreign_key(self):
         registry = self.init_registry(column_with_foreign_key)
         registry.Test.insert(name='test')
         registry.Test2.insert(test='test')
+        assert ModelAttribute('Model.Test2', 'test').get_fk_remote(
+            registry) == 'test.name'
 
     def test_column_with_foreign_key_with_schema(self, db_schema):
         registry = self.init_registry(column_with_foreign_key_with_schema)
@@ -315,8 +320,11 @@ class TestColumns:
 
     def test_string_query_False(self):
         registry = self.init_registry(simple_column, ColumnType=String)
-        test = registry.Test.insert()
-        self.registry.Test.query().filter_by(id=test.id).update({'col': False})
+        Test = registry.Test
+        test = Test.insert()
+        Test.execute_sql_statement(
+            Test.update_sql_statement().where(Test.id == test.id).values(
+                col=False))
         self.registry.expire(test, ['col'])
         assert test.col == ''
 
@@ -334,6 +342,18 @@ class TestColumns:
         assert res != 'col'
         del Configuration.configuration['default_encrypt_key']
 
+    @pytest.mark.skipif(not has_cryptography,
+                        reason="cryptography is not installed")
+    def test_string_with_encrypt_key_by_class_method(self):
+        registry = self.init_registry(simple_column, ColumnType=String,
+                                      encrypt_key='meth_secretkey')
+        test = registry.Test.insert(col='col')
+        registry.session.commit()
+        assert test.col == 'col'
+        res = registry.execute('select col from test where id = %s' % test.id)
+        res = res.fetchall()[0][0]
+        assert res != 'col'
+
     def test_string_with_size(self):
         registry = self.init_registry(
             simple_column, ColumnType=String, size=100)
@@ -349,6 +369,14 @@ class TestColumns:
         assert test.col == 'col'
         assert registry.execute('Select col from test').fetchone()[0] != 'col'
 
+    @pytest.mark.skipif(not has_passlib,
+                        reason="passlib is not installed")
+    def test_password_with_foreign_key(self):
+        with pytest.raises(FieldException):
+            self.init_registry(simple_column, ColumnType=Password,
+                               crypt_context={'schemes': ['md5_crypt']},
+                               foreign_key='Model.System.Blok=>name')
+
     def test_text_with_False(self):
         registry = self.init_registry(simple_column, ColumnType=Text)
         test = registry.Test.insert(col=False)
@@ -368,8 +396,11 @@ class TestColumns:
 
     def test_text_query_False(self):
         registry = self.init_registry(simple_column, ColumnType=Text)
-        test = registry.Test.insert()
-        self.registry.Test.query().filter_by(id=test.id).update({'col': False})
+        Test = registry.Test
+        test = Test.insert()
+        Test.execute_sql_statement(
+            Test.update_sql_statement().where(Test.id == test.id).values(
+                col=False))
         self.registry.expire(test, ['col'])
         assert test.col == ''
 
@@ -457,15 +488,18 @@ class TestColumns:
         d = datetime.datetime(2020, 7, 3, 18, 59, 0)
         d = add_timezone_on_datetime(d, timezone)
         registry = self.init_registry(simple_column, ColumnType=dt_column_type)
-        test = registry.Test.insert()
-        registry.Test.query().update(dict(col=d))
+        Test = registry.Test
+        test = Test.insert()
+        Test.execute_sql_statement(Test.update_sql_statement().values(col=d))
         registry.refresh(test)
         assert test.col == d
 
     def test_datetime_by_query_none_value(self, dt_column_type):
         registry = self.init_registry(simple_column, ColumnType=dt_column_type)
-        test = registry.Test.insert()
-        registry.Test.query().update(dict(col=None))
+        Test = registry.Test
+        test = Test.insert()
+        Test.execute_sql_statement(Test.update_sql_statement().values(
+            col=None))
         assert test.col is None
 
     @pytest.mark.skipif(sgdb_in(['MySQL', 'MariaDB', 'MsSQL']),
@@ -474,9 +508,10 @@ class TestColumns:
         timezone = pytz.timezone(time.tzname[0])
         now = datetime.datetime.now().replace(tzinfo=timezone)
         registry = self.init_registry(simple_column, ColumnType=dt_column_type)
-        test = registry.Test.insert()
-        registry.Test.query().update(
-            dict(col=now.strftime('%Y-%m-%d %H:%M:%S.%f%z')))
+        Test = registry.Test
+        test = Test.insert()
+        Test.execute_sql_statement(Test.update_sql_statement().values(
+            col=now.strftime('%Y-%m-%d %H:%M:%S.%f%z')))
         registry.expire(test, ['col'])
         assert test.col == now
 
@@ -486,9 +521,10 @@ class TestColumns:
         timezone = pytz.timezone(time.tzname[0])
         now = timezone.localize(datetime.datetime.now())
         registry = self.init_registry(simple_column, ColumnType=dt_column_type)
-        test = registry.Test.insert()
-        registry.Test.query().update(
-            dict(col=now.strftime('%Y-%m-%d %H:%M:%S.%f%Z')))
+        Test = registry.Test
+        test = Test.insert()
+        Test.execute_sql_statement(Test.update_sql_statement().values(
+            col=now.strftime('%Y-%m-%d %H:%M:%S.%f%Z')))
         registry.expire(test, ['col'])
         assert test.col == now
 
@@ -498,9 +534,10 @@ class TestColumns:
         timezone = pytz.timezone(time.tzname[0])
         now = timezone.localize(datetime.datetime.now())
         registry = self.init_registry(simple_column, ColumnType=dt_column_type)
-        test = registry.Test.insert()
-        registry.Test.query().update(
-            dict(col=now.strftime('%Y-%m-%d %H:%M:%S.%f')))
+        Test = registry.Test
+        test = Test.insert()
+        Test.execute_sql_statement(Test.update_sql_statement().values(
+            col=now.strftime('%Y-%m-%d %H:%M:%S.%f')))
         registry.expire(test, ['col'])
         assert test.col == now
 
@@ -510,9 +547,10 @@ class TestColumns:
         timezone = pytz.timezone(time.tzname[0])
         now = timezone.localize(datetime.datetime.now())
         registry = self.init_registry(simple_column, ColumnType=dt_column_type)
-        test = registry.Test.insert()
-        registry.Test.query().update(
-            dict(col=now.strftime('%Y-%m-%d %H:%M:%S')))
+        Test = registry.Test
+        test = Test.insert()
+        Test.execute_sql_statement(Test.update_sql_statement().values(
+            col=now.strftime('%Y-%m-%d %H:%M:%S')))
         registry.expire(test, ['col'])
         assert test.col == now.replace(microsecond=0)
 
@@ -742,7 +780,9 @@ class TestColumns:
             simple_column, ColumnType=Selection, selections=SELECTIONS)
         registry.Test.insert(col=SELECTIONS[0][0])
         with pytest.raises(StatementError):
-            registry.Test.query().update({'col': 'bad value'})
+            registry.execute(
+                registry.Test.update_sql_statement().values(
+                    {'col': 'bad value'}))
 
     def test_selection_like_comparator(self):
         SELECTIONS = [
@@ -1094,6 +1134,15 @@ class TestColumns:
         assert test.col.name == 'France'
         assert registry.execute('Select col from test').fetchone()[0] == 'FRA'
 
+    @pytest.mark.skipif(not has_pycountry, reason="pycountry is not installed")
+    def test_pycoundtry_at_insert_with_obj(self):
+        registry = self.init_registry(simple_column, ColumnType=Country)
+        fr = pycountry.countries.get(alpha_2='FR')
+        test = registry.Test.insert(col=fr)
+        assert test.col is pycountry.countries.get(alpha_2='FR')
+        assert test.col.name == 'France'
+        assert registry.execute('Select col from test').fetchone()[0] == 'FRA'
+
     @pytest.mark.skipif(not has_pycountry, reason="pycountry is not installed")
     def test_pycoundtry_at_insert_with_alpha_3(self):
         registry = self.init_registry(
@@ -1290,6 +1339,25 @@ class TestColumnsAutoDoc:
         self.call_autodoc(Country, mode='alpha_3')
 
 
+class Test_convert_string_to_datetime:
+
+    def test_with_none(self):
+        assert convert_string_to_datetime(None) is None
+
+    def test_with_datetime(self):
+        now = datetime.datetime.now()
+        assert convert_string_to_datetime(now) is now
+
+    def test_with_date(self):
+        today = datetime.date.today()
+        now = datetime.datetime.combine(today, datetime.datetime.min.time())
+        assert convert_string_to_datetime(today) == now
+
+    def test_with_other(self):
+        with pytest.raises(FieldException):
+            convert_string_to_datetime(1)
+
+
 class TestCompareColumn:
 
     def same_type(self, col1, col2):
