@@ -17,12 +17,12 @@ from anyblok.relationship import Many2Many
 from contextlib import contextmanager
 from sqlalchemy import (
     MetaData, Table, Column, Integer, String, Boolean, TEXT,
-    CheckConstraint, ForeignKey
+    CheckConstraint, ForeignKey, text
 )
 from sqlalchemy.dialects.mysql.types import TINYINT
 from sqlalchemy.dialects.mssql.base import BIT
 from anyblok import Declarations
-from sqlalchemy.exc import InternalError, IntegrityError, OperationalError
+from sqlalchemy.exc import IntegrityError
 from anyblok.config import Configuration
 from .conftest import init_registry, drop_database, create_database
 from anyblok.common import naming_convention
@@ -47,7 +47,7 @@ def cnx(registry):
     try:
         yield cnx
     except Exception:
-        cnx.execute("rollback")
+        cnx.execute(text("rollback"))
         raise
 
 
@@ -574,7 +574,7 @@ class TestMigration:
 
     def test_detect_drop_index(self, registry):
         with cnx(registry) as conn:
-            conn.execute("""CREATE INDEX other_idx ON test (other);""")
+            conn.execute(text("CREATE INDEX other_idx ON test (other);"))
         report = registry.migration.detect_changed()
         assert report.log_has("Drop index other_idx on test")
         report.apply_change()
@@ -584,7 +584,7 @@ class TestMigration:
     def test_detect_drop_anyblok_index(self, registry):
         with cnx(registry) as conn:
             conn.execute(
-                """CREATE INDEX anyblok_ix_test__other ON test (other);""")
+                text("CREATE INDEX anyblok_ix_test__other ON test (other);"))
         report = registry.migration.detect_changed()
         assert report.log_has("Drop index anyblok_ix_test__other on test")
         report.apply_change()
@@ -594,7 +594,7 @@ class TestMigration:
 
     def test_detect_drop_index_with_reinit_indexes(self, registry):
         with cnx(registry) as conn:
-            conn.execute("""CREATE INDEX other_idx ON test (other);""")
+            conn.execute(text("CREATE INDEX other_idx ON test (other);"))
         registry.migration.reinit_indexes = True
         report = registry.migration.detect_changed()
         assert report.log_has("Drop index other_idx on test")
@@ -604,7 +604,7 @@ class TestMigration:
 
     def test_detect_drop_index_with_reinit_all(self, registry):
         with cnx(registry) as conn:
-            conn.execute("""CREATE INDEX other_idx ON test (other);""")
+            conn.execute(text("CREATE INDEX other_idx ON test (other);"))
         registry.migration.reinit_all = True
         report = registry.migration.detect_changed()
         assert report.log_has("Drop index other_idx on test")
@@ -1037,6 +1037,13 @@ class TestMigration:
         assert not(
             report.log_has("Drop check constraint ck_other on test"))
 
+    @pytest.mark.skipif(
+        sgdb_in(['MySQL', 'MariaDB']),
+        reason=(
+            "Modification of schema create an implicite commit "
+            "with MySQL and MariaDB, save point is by passed for them"
+        )
+    )
     def test_savepoint(self, registry):
         Test = registry.Test
         self.fill_test_table(registry)
@@ -1047,14 +1054,6 @@ class TestMigration:
         assert Test.query().count() == 10
         registry.migration.release_savepoint('test')
 
-    @pytest.mark.skipif(sgdb_in(['MsSQL']),
-                        reason="No error when rollback to released save point")
-    def test_savepoint_without_rollback(self, registry):
-        registry.migration.savepoint('test')
-        registry.migration.release_savepoint('test')
-        with pytest.raises((InternalError, OperationalError)):
-            registry.migration.rollback_savepoint('test')
-
 
 @pytest.fixture()
 def registry_plugin(request, clean_db, bloks_loaded):
