@@ -13,6 +13,7 @@ from anyblok.relationship import Many2One
 from anyblok.field import Function
 from datetime import date
 from .conftest import init_registry
+from sqlalchemy import func
 
 
 register = Declarations.register
@@ -171,6 +172,10 @@ def single_table_poly():
             })
             return mapper_args
 
+        @classmethod
+        def default_filter_on_sql_statement(cls, statement):
+            return statement.where(cls.type_entity == 'manager')
+
 
 @pytest.fixture(scope="class")
 def registry_single_table_poly(request, bloks_loaded):
@@ -198,6 +203,86 @@ class TestSingleTablePoly:
         engineer_pks = registry.Engineer.get_primary_keys()
         assert employee_pks == engineer_pks
 
+    def test_select_sql_statement(self, registry_single_table_poly):
+        registry = registry_single_table_poly
+        Employee = registry.Employee
+        Engineer = registry.Engineer
+        Manager = registry.Manager
+        for index in range(3):
+            Employee.insert(name='Employee %d' % index)
+            Engineer.insert(name='Engineer %d' % index)
+            Manager.insert(name='Manager %d' % index)
+
+        for Model in (Employee, Engineer):
+            assert Model.execute_sql_statement(
+                Model.select_sql_statement(func.count(Model.id))
+            ).scalars().one() == 9
+
+        assert Manager.execute_sql_statement(
+            Manager.select_sql_statement(func.count(Manager.id))
+        ).scalars().one() == 3
+
+    def test_update_sql_statement(self, registry_single_table_poly):
+        registry = registry_single_table_poly
+        Employee = registry.Employee
+        Engineer = registry.Engineer
+        Manager = registry.Manager
+        for index in range(3):
+            Employee.insert(name='Employee %d' % index)
+            Engineer.insert(name='Engineer %d' % index)
+            Manager.insert(name='Manager %d' % index)
+
+        for Model in (Employee, Engineer):
+            assert Model.execute_sql_statement(
+                Model.update_sql_statement().values(name='other')
+            ).rowcount == 9
+
+        assert Manager.execute_sql_statement(
+            Manager.update_sql_statement().values(name="another")
+        ).rowcount == 3
+
+    def test_delete_sql_statement_1(self, registry_single_table_poly):
+        registry = registry_single_table_poly
+        Employee = registry.Employee
+        Engineer = registry.Engineer
+        Manager = registry.Manager
+        for index in range(3):
+            Employee.insert(name='Employee %d' % index)
+            Engineer.insert(name='Engineer %d' % index)
+            Manager.insert(name='Manager %d' % index)
+
+        assert Employee.execute_sql_statement(
+            Employee.delete_sql_statement()
+        ).rowcount == 9
+
+    def test_delete_sql_statement_2(self, registry_single_table_poly):
+        registry = registry_single_table_poly
+        Employee = registry.Employee
+        Engineer = registry.Engineer
+        Manager = registry.Manager
+        for index in range(3):
+            Employee.insert(name='Employee %d' % index)
+            Engineer.insert(name='Engineer %d' % index)
+            Manager.insert(name='Manager %d' % index)
+
+        assert Engineer.execute_sql_statement(
+            Engineer.delete_sql_statement()
+        ).rowcount == 9
+
+    def test_delete_sql_statement_3(self, registry_single_table_poly):
+        registry = registry_single_table_poly
+        Employee = registry.Employee
+        Engineer = registry.Engineer
+        Manager = registry.Manager
+        for index in range(3):
+            Employee.insert(name='Employee %d' % index)
+            Engineer.insert(name='Engineer %d' % index)
+            Manager.insert(name='Manager %d' % index)
+
+        assert Manager.execute_sql_statement(
+            Manager.delete_sql_statement()
+        ).rowcount == 3
+
 
 def multi_table_poly_mixins():
     @register(Mixin)
